<?php

use Imoje\Payment\Api;
use Imoje\Payment\Util;

/**
 * Class WC_Gateway_ImojeTwisto
 */
class WC_Gateway_ImojePaylater extends WC_Gateway_Imoje_Api_Abstract
{

	/**
	 *
	 */
	const PAYMENT_METHOD_NAME = 'imoje_paylater';

	/**
	 * Constructor
	 */
	public function __construct()
	{
		parent::__construct(self::PAYMENT_METHOD_NAME);

		if(is_checkout() && Helper::check_is_config_value_selected($this->get_option('enabled'))) {
			$this->imoje_service = $this->get_service_active();
		}
	}

	/**
	 * @inheritDoc
	 */
	protected function verify_availability($cart_total, $payment_method = '')
	{

		return parent::verify_availability($cart_total, Util::getPaymentMethod('imoje_paylater'));
	}

	/**
	 * @return void
	 */
	public function payment_fields()
	{
		parent::payment_fields();
		$this->render_channels([Util::getPaymentMethod('imoje_paylater')]);
		$this->render_regulations();
		$this->render_twisto_regulations();
	}

	/**
	 * @return void
	 */
	protected function render_twisto_regulations() {

		load_template( dirname( __DIR__ ) . '/templates/twisto/regulation.php', false );
	}

	/**
	 * @param WC_Order $order
	 * @param string   $payment_method
	 * @param string   $payment_method_channel
	 *
	 * @return string
	 */
	protected function prepare_data($order, $payment_method = '', $payment_method_channel = '')
	{

		return $this->imoje_api->prepareData(
			$order->get_total(),
			$order->get_currency(),
			$order->get_id(),
			$payment_method,
			$payment_method_channel,
			$this->get_return_url($order),
			$this->get_return_url($order),
			$order->get_billing_first_name(),
			$order->get_billing_last_name(),
			$order->get_billing_email(),
			Api::TRANSACTION_TYPE_SALE,
			'',
			'',
			parent::get_address_data($order),
			'',
			parent::get_invoice($order)
		);
	}
}
